@@ -111,12 +111,55 @@
     --- 气泡窗口 重构完成,并使用使用了全新的QSS来设置样式
     --- 轮播组件 重构完成
     --- 以及更新部分测试用例
+2023.1.21 [1.2.17.8]
+    --- 状态栏 无法实时跟随窗口,需要手动的调用 updateStatusSize()
+# ====== 从 2.2.17.8 版本开始 所有的样式将有全新的自定义QSS来代替
+2023.1.31 [2.2.17.8]
+    --- 重构了整个widgets项目,将原本的widgets移动到abandonCase目
+        -- 目前只有 borderlessWidget 可用,主窗口,标题栏,状态栏,还在编写中
+    --- 从 2.2.17.8这个版本开始所有的样式将有全新的自定义QSS来代替,并且不兼容前面的版本
+        --- 支持自定义QSS的已经在文档中标出
+    --- 优化了部分控件的代码,删除了一些不常用的控件,和测试用例
+    --- 修改了大部分控件的继承对象
+2023.2.9 [2.3.17.8]
+    --- 感谢! PyQt5学习爱好群-(迷糊蛋der～)在2.2.17.8版本在中提出的qt版本,代码上的兼容性问题
+    --- 修复的pyside兼容性的问题,
+    --- 新增 QSS解析器 QssStyleAnalysis 
+2023.2.13 - 2023.2.15 [2.3.18.9]
+    --- 修复 QSS解析器 在追加新的属性时会覆盖原来相同属性的BUG. 目前
+        追加新的属性时,会与原来的相同属性进行融合
+    --- 新增 功能函数 loadUic 统一四个版本加载 UI文件 的函数,对外提统一的接口
+    --- 新增滑块(Slider)
+
+2023.2.18 - 2023.2.20 [2.4.18.11]
+    --- 修改原来导入导入颜色板的方式
+        原来: from PyQtGuiLib.core import ColorPalette (与这个相关文件已删除)
+        现在: from PyQtGuiLib.core import PaletteFrame
+        并更新代码,将原来的代码拆分为,获取颜色的框架,与独立的颜色区域,
+        在框架中可以嵌入不同的颜色区别,目前支持(Rect,Wheel)
+    --- 修复 QSS解析器 已知BUG,
+        修复 isSelectKey() 取值成功,但是值为0,导致整个函数返回False的BUG
+        新增 header(),parent()方法
+        并新增对 无选择器的QSS语法  
+                  color: rgb(0, 255, 127);
+                  background-color:rgb(0, 170, 0);
+        进行处理,该语法只能用过setQSS方法设置
+        新增 QSS解析器例子,位置 PyQtGuiLib -> tests -> test_QssStyleAnalysis -> eg6.py
+    --- 动态样式链接器 from PyQtGuiLib.styles import StyleLinker
+        目前仅支持 QPushButton,QLabel,QLineEdit 控件
+'''
+
+
+# -------------------------------
+'''
+    暂时搁浅的任务
+1.新无边框窗口主窗口,(还没有设计完成,暂时先放下 2023.1.31)
 '''
 
 # ===============================================
 
 '''
 记录已知BUG,但是还未修复
-轮播组件(SlideShow) 后期将重写
-
+2023.2.18 
+    LoadBar(加载进度条) -- 有BUG,窗口变化时,进度条不会跟随变化
 '''
\ No newline at end of file
