@@ -4,4 +4,6 @@ from PyQtGuiLib.core.slideShow import SlideShow
 from PyQtGuiLib.core.flowLayout import FlowLayout
 from PyQtGuiLib.core.listWidget import ListWidget
 from PyQtGuiLib.core.rollWidget import RollWidget
-from PyQtGuiLib.core.palettes.colorPalette import ColorPalette
\ No newline at end of file
+from PyQtGuiLib.core.palettes.paletteFrame import PaletteFrame
+from PyQtGuiLib.core.notice.notice import Notice,Notices
+from PyQtGuiLib.core.slider.slider import Slider
\ No newline at end of file
