@@ -2,14 +2,12 @@ from PyQtGuiLib.header import (
     PYQT_VERSIONS,
     QApplication,
     sys,
-    QWidget,
     QResizeEvent,
     QPushButton,
 )
-from random import randint
 from PyQtGuiLib.core import FlowLayout
 from PyQtGuiLib.styles import ButtonStyle
-from PyQtGuiLib.core.widgets import BorderlessWidget,TitleBar
+from PyQtGuiLib.core.widgets import BorderlessWidget
 '''
     流式布局 测试用例
 '''
@@ -18,16 +16,11 @@ class TestFlowLayout(BorderlessWidget):
     def __init__(self,*args,**kwargs):
         super().__init__(*args,**kwargs)
         self.resize(600,600)
-        # self.setWindowTitle("流式布局 测试用例")
-        self.tit = TitleBar(self)
-        self.tit.setTitleText("流式布局 测试用例")
-        # self.tit.setStyleSheet('''background-color:rgb(240, 237, 255);''')
 
         self.items = []
 
         # 流式布局
         self.flow = FlowLayout(self)
-        self.flow.setContentsMargins(20,20+self.tit.height(),20,20)
 
         # 创建 50 个 按钮
         for i in range(50):
@@ -41,13 +34,15 @@ class TestFlowLayout(BorderlessWidget):
         for i in range(5):
             self.flow.removeWidget(self.items[i])
 
-    def resizeEvent(self, event:QResizeEvent) -> None:
-        self.tit.updateTitleSize()
-        super().resizeEvent(event)
-
 if __name__ == '__main__':
     app = QApplication(sys.argv)
     win = TestFlowLayout()
+    win.setStyleSheet('''
+TestFlowLayout{
+qproperty-radius:0;
+qproperty-border:"1 solid rgba(0,0,0,255)";
+}
+    ''')
     win.show()
 
     if PYQT_VERSIONS in ["PyQt6", "PySide6"]:
